@@ -4,4 +4,4 @@
 mod error;
 mod error_3rd;
 
-pub use error::{MaybeRanged, NoteError, NoteErrorKind, Result};
+pub use error::{DiagnosticLevel, MaybeRanged, NoteError, NoteErrorKind, Result};
